@@ -4,10 +4,10 @@ from itertools import groupby
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 import sqlalchemy as sa
+from datayoga_core import utils
 from datayoga_core.block import Block as DyBlock
-from datayoga_core.block import Result
 from datayoga_core.context import Context
-from datayoga_core.utils import get_connection_details
+from datayoga_core.result import Result, Status
 
 logger = logging.getLogger("dy")
 
@@ -50,7 +50,7 @@ class Block(DyBlock):
     def init(self, context: Optional[Context] = None):
         logger.debug(f"Initializing {self.get_block_name()}")
 
-        connection = get_connection_details(self.properties.get("connection"), context)
+        connection = utils.get_connection_details(self.properties.get("connection"), context)
         db_type = connection.get("type")
         engine_url = sa.engine.URL.create(
             drivername=db_type,
@@ -111,8 +111,8 @@ class Block(DyBlock):
                             if key in record:
                                 key_to_delete[key] = record[key]
                             else:
-                                logger.warning(f"{key} key does not exist for record:\n\{record}")
-                                record[Block.RESULT_FIELD] = Result.REJECTED
+                                logger.warning(f"{key} key does not exist for record:\n{record}")
+                                record[Block.RESULT_FIELD] = Result(Status.REJECTED, f"{key} key does not exist")
                                 break
 
                         keys_to_delete.append(key_to_delete)
@@ -120,10 +120,10 @@ class Block(DyBlock):
                     self.conn.execute(self.delete_stmt, keys_to_delete)
                 else:
                     for record in records:
-                        record[Block.RESULT_FIELD] = Result.REJECTED
+                        record[Block.RESULT_FIELD] = Result(Status.REJECTED, f"{opcode} - unsupported opcode")
                     logger.warning(f"{opcode} - unsupported opcode")
         else:
             logger.debug(f"Inserting {len(data)} record(s) to {self.table} table")
             self.conn.execute(self.tbl.insert(), data)
 
-        return DyBlock.produce_data_and_results(data)
+        return utils.produce_data_and_results(data)
