@@ -1,4 +1,5 @@
 import logging
+from abc import abstractmethod
 from typing import Any, Dict, Generator, List, TypedDict
 
 from .block import Block
@@ -9,16 +10,17 @@ Message = TypedDict("Message", msg_id=str, value=Dict[str, Any])
 
 class Producer(Block):
 
+    @abstractmethod
     def produce(self) -> Generator[Message, None, None]:
-        """ Produces data (abstract, should be implemented by the sub class)
+        """ Produces data
 
         Returns:
             Generator[Message]: Produced data
         """
-        pass
+        raise NotImplementedError
 
     def ack(self, msg_ids: List[str]):
-        """ Sends acknowledge for the message IDs of the records that have been processed (abstract, should be implemented by the sub class)
+        """ Sends acknowledge for the message IDs of the records that have been processed
 
         Args:
             msg_ids (List[str]): Message IDs
